==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/lv.js <==
﻿/*
 * Latvian language file.
 *
 * Initial Author: vebero (vebero@inbox.lv)
 *
 * Author: 
 */

var theUILang =
{
 General			: "Galvenā",
 Downloads			: "Lejupielādes",
 Connection			: "Savienojumi",
 BitTorrent			: "BitTorrent",
 Advanced			: "Papildus",
 User_Interface 		: "Lietotāja interfeiss",
 Confirm_del_torr		: "Veikt apstiprināšanu dzēšot torentus",
 Update_GUI_every		: "Atjaunot GUI ik pēc",
 ms				: "ms",
 Alt_list_bckgnd		: "Izmainīt saraksta fona krāsu",
 Show_cat_start 		: "Rādīt kategorijas, kad startē WebUI",
 Show_det_start 		: "Rādīt detaļas, kad startē WebUI",
 Dnt_start_down_auto		: "Nesākt automātisku failu vilkšanu",
 Listening_Port 		: "Savienojuma porti",
 Port_f_incom_conns		: "Ports ienākošajiem savienojumiem",
 Rnd_port_torr_start		: "Mainīt portu pie katras rTorrent palaišanas",
 Type				: "Tips",
 Bandwidth_Limiting		: "Līnijas limiti",
 Global_max_upl 		: "Max augšupielādes ātrums",
 unlimited			: "bezgalīgs",
 Glob_max_downl 		: "Max lejupielādes ātrums",
 Add_bittor_featrs		: "Papildus BitTorrent funkcijas",
 En_DHT_ntw			: "Ieslēgt DHT tīklu",
 Peer_exch			: "Iesaistīto apmaiņa",
 Ip_report_track		: "IP/PC, ziņojumu sūtīšanai trakerim",
 Disabled			: "Izslēgts",
 Enabled			: "Ieslēgts",
 ruTorrent_settings		: "Atribūti",
 Doesnt_support 		: "ruTorrent neatbalsta tavu interneta pārlūku.",
 Name				: "Nosaukums",
 Status 			: "Statuss",
 Size				: "Izmērs",
 Done				: "Izpildīti",
 Downloaded			: "Novilkts",
 Uploaded			: "Izdalīts",
 Ratio				: "Attiecība",
 DL				: "L. ātrums",
 UL				: "A. ātrums",
 ETA				: "Laiks",
 Label				: "Grupa",
 Peers				: "Iesaistītie",
 Seeds				: "Devēji",
 Remaining			: "Atlicis",
 Priority			: "Prioritāte",
 Not_torrent_file		: "Failam ir jābūt .torrent failam.",
 Pausing			: "Nopauzēts",
 Seeding			: "Dod",
 Downloading			: "Lejupielādē",
 Checking			: "Pārbauda",
 Error				: "Kļūda",
 Queued 			: "Gaida rindā",
 Finished			: "Pabeigts",
 Stopped			: "Apturēts",
 Request_timed_out		: "Pieprasījums rTorrent ir pārtraukts.",
 Start				: "Sākt",
 Pause				: "Pauze",
 Stop				: "Apturēt",
 Force_recheck			: "Piespiedu pārbaude",
 New_label			: "Jauna grupa...",
 Remove_label			: "Izdzēst grupu",
 Labels 			: "Grupa",
 Remove 			: "Izmest",
 Delete_data			: "Dzēst datus",
 Remove_and			: "Izmest un",
 Details			: "Detaļas...",
 Properties			: "Rekvizīti...",
 of				: "no", //this two creates line
 connected			: "ir savienoti", //  XX of YY connected
 High_priority			: "Augsta",
 Normal_priority		: "Normāla",
 Low_priority			: "Zema",
 Dont_download			: "Nevilkt",
 Files				: "Faili",
 Logger 			: "Žurnāls",
 s				: "s", // part of "KB/s"
 bytes				: "baiti",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Ielādē...",
 Torrent_file			: "Torenta fails",
 Torrent_URL			: "Torenta adrese",
 Torrent_properties		: "Torenta rekvizīti",
 Trackers			: "Trakeri",
 Bandwidth_sett 		: "Līnijas iestatījumi",
 Number_ul_slots		: "Augšupielādes slotu skaits: [tukšs: pēc noklusējuma]",
 Peer_ex			: "Iesaistīto apmaiņa",
 Enter_label_prom		: "Izveidojiet jaunu grupu izvēlētajiem torentiem",
 Remove_torrents		: "Izmest torentu(s)",
 Rem_torrents_prompt		: "Vai tiešām vēlaties dzēst atzīmēto torentu(s)?",
 All				: "Visi",
 Active 			: "Aktīvi",
 Inactive			: "Neaktīvi",
 No_label			: "Bez grupas",
 Transfer			: "Pārsūtīti",
 Time_el			: "Patērētais laiks",
 Share_ratio			: "A/L attiecība",
 Down_speed			: "Lejupiel. ātrums",
 Ul_speed			: "Augšupiel. ātrums",
 Wasted 			: "Izniekoti",
 Tracker			: "Trakeris",
 Track_URL			: "Trakera adrese",
 Track_status			: "Trakera statuss",
 Created_on			: "Izveidots",
 Save_as			: "Saglabāt kā",
 Comment			: "Komentārs",
 add_button			: "Pievienot failu",
 add_url			: "Pievienot adresi",
 ok				: "Labi",
 Cancel 			: "Atcelt",
 mnu_add			: "Pievienot torentu",
 mnu_remove			: "Izmest",
 mnu_start			: "Sākt",
 mnu_pause			: "Pauze",
 mnu_stop			: "Apturēt",
 mnu_rss			: "RSS lejuplādētājs",
 mnu_settings			: "Atribūti",
 mnu_search			: "Meklēt",
 mnu_lang			: "Valoda",
 torrent_add			: "Pievienot torentu", /*Caption of torrent add box*/
 time_w 			: "w ", /*for x weeks*/
 time_d 			: "d ", /*for x days remaining*/
 time_h 			: "h ", /*for x hours remaining*/
 time_m 			: "m ", /*for x minutes remaining*/
 time_s 			: "s ", /*for x seconds remaining*/
 Base_directory 		: "Directory",
 Number_Peers_min		: "Minimum number of peers",
 Number_Peers_max		: "Maximum number of peers",
 Tracker_Numwant		: "Wished number of peers",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting 		: "Other Limitations",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Maximum memory usage",
 Glob_max_files 		: "Maximum number of open files",
 Glob_max_http			: "Maximum number of open http connections",
 Other_sett			: "Other",
 Directory_For_Dl		: "Default directory for downloads",
 Check_hash			: "Check hash after download",
 Hash				: "Hash",
 DisableTracker 		: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Help",
 Speed				: "Speed",
 Dont_add_tname 		: "Don't add torrent's name to path",
 Free_Disk_Space		: "Free Disk Space",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath 		: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "Help",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList 			: "As List",
 AsTree 			: "As Tree",
 Group				: "Group",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go 			: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limits",
 speedList			: "Speed Popup List (comma-separated)",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser 		: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast 		: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No 			: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details 		: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 badTempPath 			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files 		: "Queue files recreation",
 Address			: "Address",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.0.4.tar.gz: ruTorrent-4.0.4/lang/lv.js <==
﻿/*
 * Latvian language file.
 *
 * Initial Author: vebero (vebero@inbox.lv)
 *
 * Author: 
 */

var theUILang =
{
 General			: "Galvenā",
 Downloads			: "Lejupielādes",
 Connection			: "Savienojumi",
 BitTorrent			: "BitTorrent",
 Format			: "Format",
 Advanced			: "Papildus",
 User_Interface			: "Lietotāja interfeiss",
 Confirm_del_torr		: "Veikt apstiprināšanu dzēšot torentus",
 Update_GUI_every		: "Atjaunot GUI ik pēc",
 ms				: "ms",
 Alt_list_bckgnd		: "Izmainīt saraksta fona krāsu",
 Show_cat_start			: "Rādīt kategorijas, kad startē WebUI",
 Show_det_start			: "Rādīt detaļas, kad startē WebUI",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "Nesākt automātisku failu vilkšanu",
 Listening_Port			: "Savienojuma porti",
 Port_f_incom_conns		: "Ports ienākošajiem savienojumiem",
 Rnd_port_torr_start		: "Mainīt portu pie katras rTorrent palaišanas",
 Type				: "Tips",
 Bandwidth_Limiting		: "Līnijas limiti",
 Global_max_upl			: "Max augšupielādes ātrums",
 unlimited			: "bezgalīgs",
 Glob_max_downl			: "Max lejupielādes ātrums",
 Add_bittor_featrs		: "Papildus BitTorrent funkcijas",
 En_DHT_ntw			: "Ieslēgt DHT tīklu",
 Peer_exch			: "Iesaistīto apmaiņa",
 Ip_report_track		: "IP/PC, ziņojumu sūtīšanai trakerim",
 Disabled			: "Izslēgts",
 Enabled			: "Ieslēgts",
 ruTorrent_settings		: "Atribūti",
 Doesnt_support			: "ruTorrent neatbalsta tavu interneta pārlūku.",
 Name				: "Nosaukums",
 Status				: "Statuss",
 Size				: "Izmērs",
 Done				: "Izpildīti",
 Downloaded			: "Novilkts",
 Uploaded			: "Izdalīts",
 Ratio				: "Attiecība",
 DL				: "L. ātrums",
 UL				: "A. ātrums",
 ETA				: "Laiks",
 Label				: "Grupa",
 Peers				: "Iesaistītie",
 Seeds				: "Devēji",
 Remaining			: "Atlicis",
 Priority			: "Prioritāte",
 Not_torrent_file		: "Failam ir jābūt .torrent failam.",
 Pausing			: "Nopauzēts",
 Seeding			: "Dod",
 Downloading			: "Lejupielādē",
 Checking			: "Pārbauda",
 Error				: "Kļūda",
 Queued				: "Gaida rindā",
 Finished			: "Pabeigts",
 Stopped			: "Apturēts",
 Request_timed_out		: "Pieprasījums rTorrent ir pārtraukts.",
 Start				: "Sākt",
 Pause				: "Pauze",
 Stop				: "Apturēt",
 Force_recheck			: "Piespiedu pārbaude",
 New_label			: "Jauna grupa...",
 Remove_label			: "Izdzēst grupu",
 Labels				: "Grupa",
 Remove				: "Izmest",
 Delete_data			: "Dzēst datus",
 Remove_and			: "Izmest un",
 Details			: "Detaļas...",
 Properties			: "Rekvizīti...",
 of				: "no", // this two creates line
 connected			: "ir savienoti", // XX of YY connected
 High_priority			: "Augsta",
 Normal_priority		: "Normāla",
 Low_priority			: "Zema",
 Dont_download			: "Nevilkt",
 Files				: "Faili",
 Logger				: "Žurnāls",
 s				: "s", // part of "KB/s"
 bytes				: "baiti",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Ielādē...",
 Torrent_file			: "Torenta fails",
 Torrent_URL			: "Torenta adrese",
 Torrent_properties		: "Torenta rekvizīti",
 Trackers			: "Trakeri",
 Bandwidth_sett			: "Līnijas iestatījumi",
 Number_ul_slots		: "Augšupielādes slotu skaits: [tukšs: pēc noklusējuma]",
 Peer_ex			: "Iesaistīto apmaiņa",
 Enter_label_prom		: "Izveidojiet jaunu grupu izvēlētajiem torentiem",
 Remove_torrents		: "Izmest torentu(s)",
 Rem_torrents_prompt		: "Vai tiešām vēlaties dzēst atzīmēto torentu(s)?",
 All				: "Visi",
 Active				: "Aktīvi",
 Inactive			: "Neaktīvi",
 No_label			: "Bez grupas",
 Transfer			: "Pārsūtīti",
 Time_el			: "Patērētais laiks",
 Share_ratio			: "A/L attiecība",
 Down_speed			: "Lejupiel. ātrums",
 Ul_speed			: "Augšupiel. ātrums",
 Wasted				: "Izniekoti",
 Tracker			: "Trakeris",
 Track_URL			: "Trakera adrese",
 Track_status			: "Trakera statuss",
 Created_on			: "Izveidots",
 Save_as			: "Saglabāt kā",
 Comment			: "Komentārs",
 add_button			: "Pievienot failu",
 add_url			: "Pievienot adresi",
 ok				: "Labi",
 Cancel				: "Atcelt",
 mnu_add			: "Pievienot torentu",
 mnu_remove			: "Izmest",
 mnu_start			: "Sākt",
 mnu_pause			: "Pauze",
 mnu_stop			: "Apturēt",
 mnu_rss			: "RSS lejuplādētājs",
 mnu_settings			: "Atribūti",
 mnu_search			: "Meklēt",
 mnu_lang			: "Valoda",
 torrent_add			: "Pievienot torentu", /*Caption of torrent add box*/
 time_w				: "w ", /*for x weeks*/
 time_d				: "d ", /*for x days remaining*/
 time_h				: "h ", /*for x hours remaining*/
 time_m				: "m ", /*for x minutes remaining*/
 time_s				: "s ", /*for x seconds remaining*/
 Base_directory			: "Directory",
 Number_Peers_min		: "Minimum number of peers",
 Number_Peers_max		: "Maximum number of peers",
 Tracker_Numwant		: "Wished number of peers",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting			: "Other Limitations",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Maximum memory usage",
 Glob_max_files			: "Maximum number of open files",
 Glob_max_http			: "Maximum number of open http connections",
 Open_label         : "Atvērt",
 Other_sett			: "Other",
 Directory_For_Dl		: "Default directory for downloads",
 Check_hash			: "Check hash after download",
 Hash				: "Hash",
 DisableTracker			: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Help",
 Speed				: "Speed",
 Dont_add_tname			: "Don't add torrent's name to path",
 Free_Disk_Space		: "Free Disk Space",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath			: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "Help",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList				: "As List",
 AsTree				: "As Tree",
 Group				: "Group",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go				: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limits",
 speedList			: "Speed Popup List (comma-separated)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser			: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast			: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showStateLabelSize		: "Show state size",
 showLabelSize			: "Show label size",
 showSearchLabelSize		: "Show search size",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No				: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details			: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Address",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
